{% load i18n wagtailadmin_tags %}
{% rawformattedfield field=field %}
<div class="w-field__wrapper">
    {% if media.thumbnail %}
        <a href="{{ media.thumbnail.url }}">{% icon name="image" classname="middle" %}&nbsp; {{ media.thumbnail_filename }}</a><br /><br />
    {% endif %}

    {{ field }}
</div>
{% endrawformattedfield %}
