{% load i18n wagtailadmin_tags %}
{% rawformattedfield field=field %}
    <a href="{{ media.url }}">{% icon name="media" classname="middle" %}&nbsp; {{ media.filename }}</a><br /><br />
    {% trans "Change media file:" %}
    {{ field }}
{% endrawformattedfield %}
