# Generated by Django 5.2 on 2025-05-06 16:58

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("wagtailmedia", "0004_duration_optional_floatfield"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="media",
            options={"verbose_name": "media", "verbose_name_plural": "media items"},
        ),
    ]
